package br.com.teste.android;


import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.Map;

import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpPut;
import org.apache.http.impl.client.DefaultHttpClient;
import org.json.JSONException;
import org.json.JSONObject;

import android.util.Log;


/**
 * 
 * @author Evaldo Junior
 *
 */
public class RestFulClient {
	private static final String TAG = "Client-RestClient";
	public static final String server = "http://192.168.1.31:8080";
	
	private static String convertStreamToString(InputStream is) {
    
	    BufferedReader reader = new BufferedReader(new InputStreamReader(is));
	    StringBuilder sb = new StringBuilder();
	
	    String line = null;
	    try {
			while ((line = reader.readLine()) != null) {
				sb.append(line + "\n");
			}
	    } catch (IOException e) {
	    	e.printStackTrace();
	    } finally {
	      try {
	        is.close();
	      } catch (IOException e) {
	        e.printStackTrace();
	      }
	    }
    return sb.toString();
  }
  
  public static JSONObject get(String url, Map<String,String> params){
    
    HttpClient httpClient = new DefaultHttpClient();

    if(params != null){
      int i = 0;
      for(Map.Entry<String, String> param : params.entrySet()){
        if(i == 0){
          url += "?";
        } else {
          url += "&";
        }
        
        try {
          url += param.getKey()+"="+URLEncoder.encode(param.getValue(),"UTF-8");
        } catch (UnsupportedEncodingException e) {
          Log.e(TAG, e.getMessage());
        }
        i++;
      }
    }
    
    HttpGet httpGet = new HttpGet(url); 
    HttpResponse response = null;
    JSONObject json = null;
    try {

      response = httpClient.execute(httpGet);
      Log.i("GET status code:",response.getStatusLine().toString());
      HttpEntity entityResp = response.getEntity();
      
      if (entityResp != null) {
        InputStream instream = entityResp.getContent();
        String result = convertStreamToString(instream);
        json = new JSONObject(result);
        instream.close();
      }

    } catch (ClientProtocolException e) {
      e.printStackTrace();
    } catch (IOException e) {
      e.printStackTrace();
    } catch (JSONException e) {
      e.printStackTrace();
    }
    return json;
  }
  
  public static JSONObject post(String url, HttpEntity entityReq){
    
    HttpClient httpClient = new DefaultHttpClient();
    HttpPost httpPost = new HttpPost(url); 
    HttpResponse response = null;
    JSONObject json = null;
    try {
      httpPost.setEntity(entityReq);

      response = httpClient.execute(httpPost);
      Log.i("POST status code:",response.getStatusLine().toString());
      HttpEntity entityResp = response.getEntity();
      
      if (entityResp != null) {
        InputStream instream = entityResp.getContent();
        String result = convertStreamToString(instream);
        json = new JSONObject(result);
        instream.close();
      }

    } catch (ClientProtocolException e) {
      e.printStackTrace();
    } catch (IOException e) {
      e.printStackTrace();
    } catch (JSONException e) {
      e.printStackTrace();
    }
    return json;
  }
  
  public static JSONObject put(String url, HttpEntity entityReq){
    
    HttpClient httpClient = new DefaultHttpClient();
    HttpPut httpPut = new HttpPut(url); 
    HttpResponse response = null;
    JSONObject json = null;
    try {
      httpPut.setEntity(entityReq);
      response = httpClient.execute(httpPut);
      Log.i("PUT status code:",response.getStatusLine().toString());
      HttpEntity entityResp = response.getEntity();
      
      if (entityResp != null) {
        InputStream instream = entityResp.getContent();
        String result = convertStreamToString(instream);
        json = new JSONObject(result);
        instream.close();
      }

    } catch (ClientProtocolException e) {
      e.printStackTrace();
    } catch (IOException e) {
      e.printStackTrace();
    } catch (JSONException e) {
      e.printStackTrace();
    }
    return json;
  }
}